@@ -45,7 +45,8 @@
 
 // Pref key
 static NSString *kLastTVDBUpdateServerTime = @"MLLastTVDBUpdateServerTime";
-static NSString *kUpdatedToTheMojoWireDatabaseFormat = @"upgradedToDatabaseFormat 2.2";
+static NSString *kUpdatedToTheGreatSharkHuntDatabaseFormat = @"upgradedToDatabaseFormat 2.3";
+static NSString *kDecrapifyTitles = @"MLDecrapifyTitles";
 
 #if HAVE_BLOCK
 @interface MLMediaLibrary ()
@@ -59,7 +60,8 @@ static NSString *kUpdatedToTheMojoWireDatabaseFormat = @"upgradedToDatabaseForma
 @implementation MLMediaLibrary
 + (void)initialize
 {
-    [[NSUserDefaults standardUserDefaults] registerDefaults:@{kUpdatedToTheMojoWireDatabaseFormat : [NSNumber numberWithBool:NO]}];
+    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
+    [defaults registerDefaults:@{kUpdatedToTheGreatSharkHuntDatabaseFormat : [NSNumber numberWithBool:NO], kDecrapifyTitles : [NSNumber numberWithBool:YES]}];
 }
 
 + (id)sharedMediaLibrary
@@ -602,7 +604,10 @@ static NSString *kUpdatedToTheMojoWireDatabaseFormat = @"upgradedToDatabaseForma
     }
 #endif
 
-    file.title = [MLTitleDecrapifier decrapify:[title stringByDeletingPathExtension]];
+    if ([[[NSUserDefaults standardUserDefaults] objectForKey:kDecrapifyTitles] boolValue] == YES)
+        file.title = [MLTitleDecrapifier decrapify:[title stringByDeletingPathExtension]];
+    else
+        file.title = [title stringByDeletingPathExtension];
 
     if ([size longLongValue] < 150000000) /* 150 MB */
         file.type = kMLFileTypeClip;
@@ -664,7 +669,7 @@ static NSString *kUpdatedToTheMojoWireDatabaseFormat = @"upgradedToDatabaseForma
 
 - (BOOL)libraryNeedsUpgrade
 {
-    if (![[[NSUserDefaults standardUserDefaults] objectForKey:kUpdatedToTheMojoWireDatabaseFormat] boolValue])
+    if (![[[NSUserDefaults standardUserDefaults] objectForKey:kUpdatedToTheGreatSharkHuntDatabaseFormat] boolValue])
         return YES;
     return NO;
 }
@@ -703,6 +708,8 @@ static NSString *kUpdatedToTheMojoWireDatabaseFormat = @"upgradedToDatabaseForma
                     BOOL exists = [fileManager fileExistsAtPath:[fileURL path]];
                     if (exists)
                         emptyAlbumCounter++;
+                    else
+                        [album removeTrack:track];
                 }
             }
             if (emptyAlbumCounter == 0)
@@ -733,6 +740,8 @@ static NSString *kUpdatedToTheMojoWireDatabaseFormat = @"upgradedToDatabaseForma
                     BOOL exists = [fileManager fileExistsAtPath:[fileURL path]];
                     if (exists)
                         emptyAlbumCounter++;
+                    else
+                        [show removeEpisode:showEpisode];
                 }
             }
             if (emptyAlbumCounter == 0)
@@ -756,7 +765,7 @@ static NSString *kUpdatedToTheMojoWireDatabaseFormat = @"upgradedToDatabaseForma
     }
     [seenFiles release];
 
-    [defaults setBool:YES forKey:kUpdatedToTheMojoWireDatabaseFormat];
+    [defaults setBool:YES forKey:kUpdatedToTheGreatSharkHuntDatabaseFormat];
     [defaults synchronize];
 
     [self libraryDidAppear];
@@ -790,7 +799,8 @@ static NSString *kUpdatedToTheMojoWireDatabaseFormat = @"upgradedToDatabaseForma
                     @catch (NSException *exception) {
                         APLog(@"failed to nuke object because it disappeared in front of us");
                     }
-                }
+                } else
+                    [album removeTrack:file.albumTrack];
             }
             if (file.isShowEpisode) {
                 MLShow *show = file.showEpisode.show;
@@ -801,10 +811,11 @@ static NSString *kUpdatedToTheMojoWireDatabaseFormat = @"upgradedToDatabaseForma
                     @catch (NSException *exception) {
                         APLog(@"failed to nuke object because it disappeared in front of us");
                     }
-                }
+                } else
+                    [show removeEpisode:file.showEpisode];
             }
 #if TARGET_OS_IPHONE
-            NSString *thumbPath = [[[self thumbnailFolderPath] stringByAppendingPathComponent:[[file.objectID URIRepresentation] path]] stringByAppendingString:@".png"];
+            NSString *thumbPath = [file thumbnailPath];
             bool thumbExists = [fileManager fileExistsAtPath:thumbPath];
             if (thumbExists)
                 [fileManager removeItemAtPath:thumbPath error:nil];
