@@ -106,6 +106,11 @@ static inline NSNumber *numberFromTwoChars(char high, char low)
     return @(intFromChar(high) * 10 + intFromChar(low));
 }
 
+static inline NSNumber *numberFromThreeChars(char high, char mid, char low)
+{
+    return @(intFromChar(high) * 100 + intFromChar(mid) * 10 + intFromChar(low));
+}
+
 + (NSDictionary *)tvShowEpisodeInfoFromString:(NSString *)string
 {
     if (!string)
@@ -128,22 +133,17 @@ static inline NSNumber *numberFromTwoChars(char high, char low)
             isDigit(c(str, i+5)))
         {
             NSNumber *season = numberFromTwoChars(c(str,i+1), c(str,i+2));
-            NSNumber *episode = numberFromTwoChars(c(str,i+4), c(str,i+5));
-            NSString *tvShowName = i > 0 ? [str substringToIndex:i-1] : nil;
+            NSNumber *episode;
+            if (isDigit(c(str, i+6)))
+                episode = numberFromThreeChars(c(str,i+4), c(str,i+5), c(str,i+6));
+            else
+                episode = numberFromTwoChars(c(str,i+4), c(str,i+5));
+            NSString *tvShowName = i > 0 ? [str substringToIndex:i] : nil;
             tvShowName = tvShowName ? [[MLTitleDecrapifier decrapify:tvShowName] capitalizedString] : nil;
-            NSString *episodeName = [str substringFromIndex:i+6];
-
-            NSArray *components = [episodeName componentsSeparatedByString:@" "];
-            NSUInteger componentsCount = components.count;
 
+            NSString *episodeName = stringLength > i + 4 ? [str substringFromIndex:i+6] : nil;
             episodeName = episodeName ? [MLTitleDecrapifier decrapify:episodeName] : nil;
 
-            /* episode name is optional */
-            if ([episodeName isEqualToString:components[componentsCount - 1]])
-                episodeName = nil;
-            if (components.count > 1)
-                episodeName = [episodeName stringByReplacingOccurrencesOfString:[NSString stringWithFormat:@" %@", components[componentsCount - 1]] withString:@""];
-
             mutableDict = [[NSMutableDictionary alloc] initWithCapacity:4];
             if (season)
                 [mutableDict setObject:season forKey:@"season"];
@@ -167,9 +167,12 @@ static inline NSNumber *numberFromTwoChars(char high, char low)
             {
                 NSNumber *season = [NSNumber numberWithInt:intFromChar(c(str,i))];
                 NSNumber *episode = numberFromTwoChars(c(str,i+2), c(str,i+3));
-                NSString *tvShowName = i > 0 ? [str substringToIndex:i-1] : nil;
+                NSString *tvShowName = i > 0 ? [str substringToIndex:i] : nil;
                 tvShowName = tvShowName ? [[MLTitleDecrapifier decrapify:tvShowName] capitalizedString] : nil;
 
+                NSString *episodeName = stringLength > i + 4 ? [str substringFromIndex:i+4] : nil;
+                episodeName = episodeName ? [MLTitleDecrapifier decrapify:episodeName] : nil;
+
                 mutableDict = [[NSMutableDictionary alloc] initWithCapacity:3];
                 if (season)
                     [mutableDict setObject:season forKey:@"season"];
@@ -177,6 +180,8 @@ static inline NSNumber *numberFromTwoChars(char high, char low)
                     [mutableDict setObject:episode forKey:@"episode"];
                 if (tvShowName && ![tvShowName isEqualToString:@" "])
                     [mutableDict setObject:tvShowName forKey:@"tvShowName"];
+                if (episodeName.length > 0 && ![episodeName isEqualToString:@" "])
+                    [mutableDict setObject:[episodeName capitalizedString] forKey:@"tvEpisodeName"];
                 successfulSearch = YES;
             }
         }
